.. _install:

Install Phases - ``ORBIT.phases.install``
===============================================

ORBIT includes the following installation modules that can be used within
ProjectManager. These modules utilize SimPy to model individual processes and
their constraints due to weather and vessel interactions. For a more detailed
description of vessel scheduling within ORBIT, please see `add link`.

.. toctree::
   :maxdepth: 1

   phases/install/monopile/api_MonopileInstallation
   phases/install/scour/api_ScourProtectionInstall
   phases/install/turbine/api_TurbineInstallation
   phases/install/array/api_ArrayCableInstall
   phases/install/export/api_ExportCableInstall
   phases/install/oss/api_OffshoreSubstationInstall
   phases/install/quayside_towout/api_MooredSubInstallation
   phases/install/mooring/api_MooringSystemInstallation

..    phases/install/jacket/api_JacketInstall
